@@ -1,15 +1,18 @@
 #' Enhanced Bibliographic Entries
 #'
-#' Provides a new class \code{BibEntry} which builds on \code{\link{bibentry}} to provide enhanced
-#'   functionalilty for representing, manipulating, importing, etc. bibliographic information in BibTeX or
-#'   BibLaTeX style.
-#' @param bibtype a character string with a BibTeX entry type. See Entry Types for details.
-#' @param textVersion a character string with a text representation of the reference to optionally be employed for printing.
+#' Provides a new class \code{BibEntry} which builds on \code{\link{bibentry}}
+#' to provide enhanced functionality for representing, manipulating, importing,
+#' etc. bibliographic information in BibTeX or BibLaTeX style.
+#' @param bibtype a character string with a BibTeX entry type. See Entry Types
+#' for details.
+#' @param textVersion a character string with a text representation of the
+#' reference to optionally be employed for printing.
 #' @param header a character string with optional header text.
 #' @param footer a character string with optional footer text.
 #' @param key	a character string giving the citation key for the entry.
-#' @param ...	arguments of the form \code{tag = value} giving the fields of the entry, with \code{tag} and
-#'   \code{value} the name and value of the field, respectively. Arguments with empty values are dropped. See
+#' @param ...	arguments of the form \code{tag = value} giving the fields
+#' of the entry, with \code{tag} and \code{value} the name and value of the
+#' field, respectively. Arguments with empty values are dropped. See
 #'   Entry Fields for details.
 #' @param other list; additional way to specify fields and their values
 #' @param mheader string; optional \dQuote{outer} header text
@@ -18,13 +21,13 @@
 #' @export
 #' @seealso \code{\link{bibentry}}
 #' @keywords database
-#' @import methods
 #' @importFrom utils bibentry
 #' @section Entry Types:
-#'   bibentry creates "bibentry" objects, which are modeled after BibLaTeX and BibTeX entries. The entry should
-#'   be a valid BibLaTeX or BibTeX entry type.  For a list of valid BibTeX entry types, see
-#'   \code{\link{bibentry}}.  BibLaTeX supports all entry types from BibTeX for backwards compatibility.
-#'   BibLaTeX defines following entry types
+#'   bibentry creates "bibentry" objects, which are modeled after BibLaTeX and
+#' BibTeX entries. The entry should
+#'   be a valid BibLaTeX or BibTeX entry type.  For a list of valid BibTeX entry
+#' types, see \code{\link{bibentry}}.  BibLaTeX supports all entry types from
+#' BibTeX for backwards compatibility. BibLaTeX defines following entry types
 #'   '  \itemize{
 #'    \item \emph{article} - An article in a journal, magazine, newspaper, or other periodical which forms a
 #'   self-contained unit with its own title.  Required fields: author, title, journal/journaltitle, year/date.
@@ -79,14 +82,16 @@
 #'     styles.
 #'  }
 #' @author McLean, M. W. \email{mathew.w.mclean@@gmail.com}
-#' @note Date fields are parsed using the locale specified by `Sys.getlocale("LC_TIME")` (relevant
-#' when specifying a character \sQuote{month} field, instead of the recommended integer format)
+#' @note Date fields are parsed using the locale specified by
+#' \code{Sys.getlocale("LC_TIME")} (relevant when specifying a character
+#' \sQuote{month} field, instead of the recommended integer format)
 #'
 #' Name list fields (author, editor, etc.) should be specified as they would be for
 #' BibTeX/BibLaTeX; e.g. \code{author = "Doe, Jane and Smith, Bob A."}.
 #' @references BibLaTeX manual \url{https://mirror.pregi.net/tex-archive/macros/latex/contrib/biblatex/doc/biblatex.pdf}
-#' @details The BibEntry objects created by BibEntry can represent an arbitrary positive number of references,
-#'   as with \code{bibentry}, but many additional methods are defined for building and manipulating a database
+#' @details The BibEntry objects created by BibEntry can represent an
+#' arbitrary positive number of references, as with \code{bibentry}, but
+#' many additional methods are defined for building and manipulating a database
 #'   of references.
 #' @examples
 #' BibEntry(bibtype = "Article", key = "mclean2014", title = "An Article Title",
@@ -100,80 +105,86 @@
 #' bib
 #' toBiblatex(bib)
 BibEntry <- function (bibtype, textVersion = NULL, header = NULL, footer = NULL,
-                      key = NULL, ..., other = list(), mheader = NULL, mfooter = NULL){
+                      key = NULL, ..., other = list(), mheader = NULL,
+                      mfooter = NULL){
   BibTeX_names <- names(BibLaTeX_entry_field_db)
   args <- c(list(...), other)
   if (!length(args))
     return(structure(list(), class = "bibentry"))
-  if (any(sapply(names(args), .is_not_nonempty_text)))
+  if (any(vapply(names(args), .is_not_nonempty_text, FALSE)))
     stop("all fields have to be named")
   args <- c(list(bibtype = bibtype, textVersion = textVersion,
                  header = header, footer = footer, key = key), list(...))
   args <- lapply(args, .listify)
   other <- lapply(other, .listify)
-  max_length <- max(sapply(c(args, other), length))
-  args_length <- sapply(args, length)
+  max_length <- max(vapply(c(args, other), length, 0L))
+  args_length <- vapply(args, length, 0L)
   if (!all(args_length_ok <- args_length %in% c(1L, max_length)))
-    warning(gettextf("Not all arguments are of the same length, the following need to be recycled: %s",
-                     paste(names(args)[!args_length_ok], collapse = ", ")),
-            domain = NA)
+      warning(gettextf("Not all arguments are of the same length, %s: %s",
+                       "the following need to be recycled",
+                       paste(names(args)[!args_length_ok], collapse = ", ")),
+              domain = NA)
   args <- lapply(args, function(x) rep(x, length.out = max_length))
-  other_length <- sapply(other, length)
+  other_length <- vapply(other, length, 0L)
   if (!all(other_length_ok <- other_length %in% c(1L, max_length)))
-    warning(gettextf("Not all arguments are of the same length, the following need to be recycled: %s",
-                     paste(names(other)[!other_length_ok], collapse = ", ")),
-            domain = NA)
+      warning(gettextf("Not all arguments are of the same length, %s: %s",
+                       "the following need to be recycled",
+                       paste(names(other)[!other_length_ok], collapse = ", ")),
+              domain = NA)
   other <- lapply(other, function(x) rep(x, length.out = max_length))
   bibentry1 <- function(bibtype, textVersion, header = NULL,
                         footer = NULL, key = NULL, ..., other = list()) {
-    bibtype <- as.character(bibtype)
-    stopifnot(length(bibtype) == 1L)
-    pos <- match(tolower(bibtype), tolower(BibTeX_names))
-    if (is.na(pos))
-      stop(gettextf("%s has to be one of %s", sQuote("bibtype"),
-                    paste(BibTeX_names, collapse = ", ")), domain = NA)
-    bibtype <- BibTeX_names[pos]
-    rval <- c(list(...), other)
-    rval <- rval[!sapply(rval, .is_not_nonempty_text)]
-    fields <- tolower(names(rval))
-    names(rval) <- fields
-    attr(rval, "bibtype") <- bibtype
-    .BibEntryCheckBibEntry1(rval)
-    pos <- fields %in% .BibEntryNameList
-    if (any(pos)) {
-      for (i in which(pos))
-          if (!inherits(rval[[i]], "person"))
-              rval[[i]] <- ArrangeAuthors(rval[[i]])
-    }
-    pos <- fields %in% c("dateobj") | pos
-    if (any(!pos)) {
-      for (i in which(!pos))
-        rval[[i]] <- as.character(rval[[i]])
-    }
-    attr(rval, "key") <- if (is.null(key))
-      NULL
-    else as.character(key)
-    if (is.null(rval[['dateobj']])){
-      tdate <- try(ProcessDates(rval), TRUE)
-      if (!inherits(tdate, "try-error"))
-        attr(rval, 'dateobj') <- tdate
-    }else{
-      attr(rval, 'dateobj') <- rval[['dateobj']]
-      rval[['dateobj']] <- NULL
-    }
+                bibtype <- as.character(bibtype)
+                stopifnot(length(bibtype) == 1L)
+                pos <- match(tolower(bibtype), tolower(BibTeX_names))
+                if (is.na(pos))
+                  stop(gettextf("%s has to be one of %s", sQuote("bibtype"),
+                                paste(BibTeX_names, collapse = ", ")),
+                       domain = NA)
+                bibtype <- BibTeX_names[pos]
+                rval <- c(list(...), other)
+                rval <- rval[!vapply(rval, .is_not_nonempty_text, FALSE)]
+                fields <- tolower(names(rval))
+                names(rval) <- fields
+                attr(rval, "bibtype") <- bibtype
+                .BibEntryCheckBibEntry1(rval)
+                pos <- fields %in% .BibEntryNameList
+                if (any(pos)) {
+                  for (i in which(pos))
+                      if (!inherits(rval[[i]], "person"))
+                          rval[[i]] <- ArrangeAuthors(rval[[i]])
+                }
+                pos <- fields %in% c("dateobj") | pos
+                if (any(!pos)) {
+                  for (i in which(!pos))
+                    rval[[i]] <- as.character(rval[[i]])
+                }
+                attr(rval, "key") <- if (is.null(key))
+                  NULL
+                else as.character(key)
+                if (is.null(rval[['dateobj']])){
+                  tdate <- try(ProcessDates(rval), TRUE)
+                  if (!inherits(tdate, "try-error"))
+                    attr(rval, 'dateobj') <- tdate
+                }else{
+                  attr(rval, 'dateobj') <- rval[['dateobj']]
+                  rval[['dateobj']] <- NULL
+                }
 
-    if (!is.null(textVersion))
-      attr(rval, "textVersion") <- as.character(textVersion)
-    if (!.is_not_nonempty_text(header))
-      attr(rval, "header") <- paste(header, collapse = "\n")
-    if (!.is_not_nonempty_text(footer))
-      attr(rval, "footer") <- paste(footer, collapse = "\n")
-    return(rval)
-  }
+                if (!is.null(textVersion))
+                  attr(rval, "textVersion") <- as.character(textVersion)
+                if (!.is_not_nonempty_text(header))
+                  attr(rval, "header") <- paste(header, collapse = "\n")
+                if (!.is_not_nonempty_text(footer))
+                  attr(rval, "footer") <- paste(footer, collapse = "\n")
+                return(rval)
+              }
 
-  rval <- lapply(seq_along(args$bibtype), function(i) do.call("bibentry1",
-                                                              c(lapply(args, "[[", i),
-                                                                list(other = lapply(other, "[[", i)))))
+  rval <- lapply(seq_along(args$bibtype),
+                 function(i) do.call("bibentry1", c(lapply(args, "[[", i),
+                                                    list(other = lapply(other,
+                                                                        "[[",
+                                                                        i)))))
 
   if (!.is_not_nonempty_text(mheader))
     attr(rval, "mheader") <- paste(mheader, collapse = "\n")
